@@ -30,7 +30,7 @@ CONFIG = {
 }
 
 ENDPOINTS = {
-    "orders":"/wp-json/wc/v3/orders?after={0}&orderby=date&order=asc&per_page=100&page={1}&consumer_key={2}&consumer_secret={3}",
+    "orders":"/wp-json/wc/v3/orders?after={0}&orderby=date&order=asc&per_page=10&page={1}&consumer_key={2}&consumer_secret={3}",
     "reports":"/wp-json/wc/v3/reports/sales?date_min={0}&date_max={1}&consumer_key={2}&consumer_secret={3}"
 }
 
@@ -139,45 +139,50 @@ def filter_order(order):
         shipping_lines = [filter_shipping(ship) for ship in order["shipping_lines"]]
     else:
         shipping_lines = None
-
  
     try:
-     filtered = {
-        "number": int(order["number"]),
-        "store_url": CONFIG["url"],
-        "created_via": str(order["created_via"]),
-        "currency": str(order["currency"]),
-        "order_id":int(order["id"]),
-        "order_key":str(order["order_key"]),
-        "total_tax": str(order["total_tax"]),
-        "discount_tax": str(order["discount_tax"]),
-        "discount_total": str(order["discount_total"]),
-        "status":str(order["status"]),
-        "date_created":parser.parse(order["date_created"]).replace(tzinfo=tzinfo).isoformat(),
-        "date_modified":parser.parse(order["date_modified"]).replace(tzinfo=tzinfo).isoformat(),
-        "discount_total":float(order["discount_total"]),
-        "shipping_total":float(order["shipping_total"]),
-        "shipping_tax": float(order["shipping_tax"]),
-        "cart_tax": float(order["cart_tax"]),
-        "prices_include_tax": order["prices_include_tax"],
-        "customer_id": str(order["customer_id"]),
-        "customer_ip_address": str(order["customer_ip_address"]),
-        "customer_user_agent": str(order["customer_user_agent"]),
-        "customer_note": str(order["customer_note"]),
-        "coupon_lines": order["coupon_lines"],
-        "total":float(order["total"]),
-        "payment_method": str(order["payment_method"]),
-        "payment_method_title": str(order["payment_method_title"]),
-        "transaction_id": str(order["transaction_id"]),
-        "date_paid": parser.parse(order["date_paid"]).replace(tzinfo=tzinfo).isoformat(),
-        "date_completed": parser.parse(order["date_completed"]).replace(tzinfo=tzinfo).isoformat(),
-        "set_paid": order["set_paid"],
-        "shipping_lines": order["shipping_lines"],
-        "line_items":line_items,
-        "fee_lines": order["fee_lines"],
-        "refunds": order["refunds"]
-    }
+        filtered = {
+            "number": str(order["number"]),
+            "store_url": CONFIG["url"],
+            "created_via": str(order["created_via"]),
+            "currency": str(order["currency"]),
+            "order_id":int(order["id"]),
+            "order_key":str(order["order_key"]),
+            "total_tax": str(order["total_tax"]),
+            "discount_tax": str(order["discount_tax"]),
+            "discount_total": str(order["discount_total"]),
+            "status":str(order["status"]),
+            "date_created":parser.parse(order["date_created"]).replace(tzinfo=tzinfo).isoformat(),
+            "date_modified":parser.parse(order["date_modified"]).replace(tzinfo=tzinfo).isoformat(),
+            "discount_total":float(order["discount_total"]),
+            "shipping_total":float(order["shipping_total"]),
+            "shipping_tax": float(order["shipping_tax"]),
+            "cart_tax": float(order["cart_tax"]),
+            "prices_include_tax": order["prices_include_tax"],
+            "customer_id": str(order["customer_id"]),
+            "customer_ip_address": str(order["customer_ip_address"]),
+            "customer_user_agent": str(order["customer_user_agent"]),
+            "customer_note": str(order["customer_note"]),
+            "coupon_lines": order["coupon_lines"],
+            "total":float(order["total"]),
+            "payment_method": str(order["payment_method"]),
+            "payment_method_title": str(order["payment_method_title"]),
+            "transaction_id": str(order["transaction_id"]),
+        
+            "shipping_lines": order["shipping_lines"],
+            "line_items":line_items,
+            "fee_lines": order["fee_lines"],
+            "refunds": order["refunds"]
+        }
+
+        if (order["date_completed"]):
+            filtered["date_completed"]  = parser.parse(order["date_completed"]).replace(tzinfo=tzinfo).isoformat()
+        
+        if (order["date_paid"]):
+            filtered["date_paid"]  = parser.parse(order["date_paid"]).replace(tzinfo=tzinfo).isoformat()
+    
     except:
+        print(e)
         filtered = {}    
     return filtered
 
